An actor were addresses of profiled_actor are registered and collect metrics when a snapshot is taken.
self::observer actors can be registered and are notified at the end of the snapshot.
The design is done so that the data allocation is done in the aggregator code, so there is no reallocation in the profiled code (useful in the future when rtactor message passing use memory pools).